agentle.agents.templates.data\_collection.field\_spec
=====================================================

.. automodule:: agentle.agents.templates.data_collection.field_spec

   
   .. rubric:: Classes

   .. autosummary::
   
      BaseModel
      ConfigDict
      FieldSpec
      MutableSequence
   